# Setup

Sonolus.py is published on [PyPI](https://pypi.org/project/sonolus.py/), and can be installed with any package manager.

For example, you can use pip to install it:

```bash
pip install sonolus.py
```

Or add it to a project using [uv](https://docs.astral.sh/uv/getting-started/installation/):

```bash
uv add sonolus.py
```
